#### R script ########################################
# Last modfied: 2021-03-28
# File name: test_ablrtest_urca.R
# Keywords: likelihood ratio test for restrictions on 
#   "alpha" and "beta" of VEC(p) model, 
#   using ablrtest () function in Package "urca",  
# 
# Written by: Hiroshi Murao
#
# Purpose: perform the likelihood ratio test 
#     for restrictions on "alpha" and "beta", based on VEC(p) model, 
#     using ablrtest() function in Package "urca". 
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/stat_works/Pfaff_Canada/R_prg")
library(vars)
library(svars)
library(urca)

#### data preparations
data(Canada)
dim(Canada)
print("The data set of Canada")
print(Canada[1:5, ])
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]

Canada_diff <- diff(Canada, lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- Canada_diff[, c("prod", "e", "U", "rw")]
print(ys_diff[1:5, ])

#### estimate a VEC(p) model, using ca.jo() function in Package "urca"
# we use ys_level
num_lag <- 3
out_cajo <- ca.jo(y = ys_level, K = 3, type = "both", 
     type = "eigen", spec = "transitory")

summary(out_cajo)

#### info. for restriction matrices
# Estimation and testing under linear restrictions on alpha and beta 
# The VECM has been estimated subject to: 
# beta=H*phi and/or alpha=A*psi

#### make a restriction matrix "H" for beta
num_rank <- 1
num_ys <- 4
num_lag <- 3
# Hmat: (K+1) x s = 5 x 3
Hmat <- rbind(c(1, 0, 0),
              c(-1, 0, 0),
              c(0, 1, 0),
              c(0, -1, 0),
              c(0, 0, 1))

print(Hmat)

#### make a restriction matrix "A" for alpha
# Amat: K x m = 4 x 3
Amat <- rbind(c(1, 0, 0),
              c(0, 1, 0),
              c(0, 0, 0),
              c(0, 0, 1))

print(Amat)

#### LR test, using ablrtest() function in Package "urca"
out_abLR <- ablrtest(out_cajo, H = Hmat, A = Amat, r = num_rank)

summary(out_abLR)

#### end #############################################
