#### R script ########################################
# Last modfied: 2021-03-28
# File name: test_js_svars.R
# Keywords: Chi-square test for joint hypotheses,
#   based on a B-type SVAR(p), 
#   using js.test () function in Package "svars",  
# 
# Written by: Hiroshi Murao
#
# Purpose: perform the Wald test based on a B-type SVAR(p), 
#   using js.test() function in Package "svars". 
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
##########################################################
setwd("C:/book_VAR/stat_works/Pfaff_Canada/R_prg")
library(vars)
library(svars)

#### data preparations
data(Canada)
dim(Canada)
print("The data set of Canada")
print(Canada[1:5, ])
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]

Canada_diff <- diff(Canada, lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- Canada_diff[, c("prod", "e", "U", "rw")]
print(ys_diff[1:5, ])

#### estimate VAR(p), using VAR() in "vars"
## we use ys_level
num_y <- 4
num_lag <- 3
num_z <- 2

out_VAR <- vars::VAR(y = ys_level, p = num_lag, type = "both", exogen = NULL)
summary(out_VAR)

#### transform the VAR model for Package "svars" 
out_id <- id.dc(x = out_VAR)
summary(out_id)

#### get "sboot" object for Package "svars" 
num_H <- 25
out_boot <- wild.boot(out_id, nboot = 100, n.ahead = num_H)

#### make a restriction matrix
# B: 4 x 4
# B is a lower triangular matrix
B <- rbind(c(NA, 0, 0, 0), 
           c(NA, NA, 0, 0),
           c(NA, NA, NA, 0),
           c(NA, NA, NA, NA))
print(B)
# 0 positions: 5, 8, 9, 10, 13, 14, 15 => 7 0's

# restrict_No1: J x num_y^2, 7 x 16 
restrict_No1 <- rbind(c(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
                      c(0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0),
                      c(0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0),
                      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0),
                      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0),
                      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0),
                      c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0))
print(restrict_No1)

#### Wald test, using js.test() in "svars"
out_js_No1 <- js.test(x = out_boot, R = restrict_No1)
summary(out_js_No1)

#### make another restriction matrix
# restrict_No2: J x num_y^2, J x 16 
restrict_No2 <- rbind(c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0), 
                      c(0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0)) 

#### Wald test, using js.test() in "svars"
out_js_No2 <- js.test(x = out_boot, R = restrict_No2)
summary(out_js_No2)

#### end #############################################
