#### R script ########################################
# Last modfied: 2021-06-24
# File name: test_stability_vars.R
# Keywords: test of structure stability for VAR(p) or the like, 
#   using stability() function in Package "vars", 
#  
# Written by: Hiroshi Murao
#
# Purpose: perform the test of structure stability of VAR(p) or the like, 
#   using stability() function in Package "vars". 
#
# Name of data set: "Canada" in R Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars)
library(urca)

#### get data 
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]
print(ys_level[1:5, ])

ys_diff <- diff(Canada[, c("prod", "e", "U", "rw")], lag = 1)
print(ys_diff[1:5, ])

#### note on important numbers for level-VAR(p)
num_y <- 4
num_lag <- 3
num_z <- 2

#### estimate VAR(p), using VAR() function in "vars"
# Note: The use of cajorls() or the like does not work. => Use VAR() in "vars".
#
# out_VAR <- VAR(y = ys_level, p = 3, 
#    type = "both", exogen = NULL, ic = "AIC")

out_VAR <- VAR(y = ys_diff, p = 2, 
   type = "const", exogen = NULL, ic = "AIC")
summary(out_VAR)

#### stability tests, using stability() in "vars"
# type = "OLS_CUSUM"
out_OLS_CUSUM <- stability(x = out_VAR, type = "OLS-CUSUM")
plot(out_OLS_CUSUM)

# type = "Rec_CUSUM"
out_Rec_CUSUM <- stability(x = out_VAR, type = "Rec-CUSUM")
plot(out_Rec_CUSUM)

# type = "OLS-MOSUM"
out_OLS_MOSUM <- stability(x = out_VAR, type = "OLS-MOSUM", h = 0.15)
plot(out_OLS_MOSUM)

# type = "Rec-MOSUM"
out_Rec_MOSUM <- stability(x = out_VAR, type = "Rec-MOSUM", h = 0.15)
plot(out_Rec_MOSUM)

# get big plots
plot(out_OLS_CUSUM$stability$prod)
plot(out_OLS_CUSUM$stability$e)
plot(out_OLS_CUSUM$stability$U)
plot(out_OLS_CUSUM$stability$rw)

#### end #############################################
