#### R script ########################################
# Last modfied: 2021-12-29
# File name: irf_VAR_vars.R
# Keywords: impulse response analysis based on VAR(p), 
#   using VAR() function in Package "vars",
#  
# Written by: Hiroshi Murao
#
# Purpose: perform the impulse response analysis based on a VAR model,
#    using VAR() function in Package "vars".
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/stat_works/Pfaff_Canada/R_prg")
library(vars)

#### get data 
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]

Canada_diff <- diff(Canada, lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- Canada_diff[, c("prod", "e", "U", "rw")]
print(ys_diff_use[1:5, ])

#### preparational estimation, using VAR() in "vars"
# out_VAR <- VAR(y = ys_level, type = "both", p = 3, ic = "AIC")
out_VAR <- VAR(y = ys_diff, type = "const", p = 2, ic = "AIC")

summary(out_VAR)

#### impulse response function, using irf()
response = "U" = y3
irf_y3_ss <- irf(x = out_VAR, response = "U", n.ahead = 48, boot = TRUE)

#### plot graphs with the output data of irf()
plot.new()
plot(irf_y3_ss)

#### choose some data for Panel 1 of Figure 5, Pfaff (2008).
# choose impulse = "pord"
names(irf_y3_ss)
names(irf_y3_ss$irf)
print(irf_y3_ss$irf$prod)

irf_y3_s1_mean <- irf_y3_ss$irf$prod
irf_y3_s1_lo <- irf_y3_ss$Lower$prod
irf_y3_s1_up <- irf_y3_ss$Upper$prod

#### preparing for plotting
# get y_data
y_data <- cbind(irf_y3_s1_mean, irf_y3_s1_lo, irf_y3_s1_up)
colnames(y_data) <- c("mean", "lower", "upper")
# note that the values at the first row are not zero.
print(y_data)
# make initial (zero) values at the first row.
y_data <- rbind(c(0, 0, 0), y_data)
print(y_data)

# get x_data
num_row <- nrow(y_data)
x_data <- matrix(-1:(num_row - 2), nrow = num_row, ncol = 1)
print(x_data)

# min, max information
x_max <- max(x_data)
x_min <- min(x_data)
print(c(x_min, x_max))

y_min <- min(y_data[, 2])
y_max <- max(y_data[, 3])
print(c(y_min, y_max))

#### plot, using matplot().
#  response = y3 = U, shock = y1 = prod,
plot.new()

matplot(x_data, y_data, 
type = "l", lwd = 2, col = 1, 
lty = c("solid", "dotted", "dotted"), 
xlim = c(-1, 55), 
ylim = c(-1.0, 0.40), 
xlab = "time horizon (quarter)", 
ylab = "impulse response (persent)", 
main = "impulse response: response = y3 = U, shock = y1 = prod, use of SVAR()")

#### additional infromation to the graph
abline(h = 0, col = "gray")
text(x_max, y_data[(x_data == x_max), 1], labels = "irf_y3_s1", pos = 4)
text(x_max, y_data[(x_data == x_max), 2], labels = "2.5%", pos = 4)
text(x_max, y_data[(x_data == x_max), 3], labels = "97.5%", pos = 4)
# pos = 1: below,  pos = 2: left,  pos = 3: up,  pos = 4: right.

#### save the graph as a file
# dev.copy(jpg, file = "./outputs/irf_VAR_vars.jpg")
# dev.copy(pdf, file = "./outputs/irf_VAR_vars.pdf")
# dev.off()

#### end #############################################
