#### R script ########################################
# Last modfied: 2019-09-09
# File name: irf_vec2var_vars.R
# Keywords: impulse response analysis, 
#   using vec2var() function in Package "vars", 
#   a VEC model is transformed to a VAR model, 
#   
# Written by: Hiroshi Murao
#
# Purpose: perform the impulse response analysis, using vec2var()
#
# Related journal paper: Breitung J, Bruggemann R, Lutkepohl H (2004) 
# "Structural Vector Autoregressive Modeling and Impulse Responses". 
# In Lutkepohl H, Kratzig M (eds), "Applied Time Series Econometrics", 
# chapter 4, pp.159-196, Cambridge University Press, 
# ISBN 0-521-83919-X (hardback). - ISBN 0-521-54787-3 (paperback)  
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
# setwd("C:/school/stat_homework/time_VAR/Breitung/R_prg")
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars)

#### get data 
data(Canada)
print("Check the data@set of Canada")
print(Canada)
# summary(Canada)

#### Johansen procedure for VAR, using ca.jo()
out_cajo <- ca.jo(Canada[, c("prod", "e", "U", "rw")], 
type = "trace", ecdet = "trend", K = 3, spec = "transitory")

#### Transform a VECM to VAR in levels, using vec2var()
out_vec2var <- vec2var(out_cajo, r = 1)
print(out_vec2var)

#### impulse response function, using irf()
# response = "U" = y3
irf_y3_ss <- irf(out_vec2var, response = "U", n.ahead = 48, boot = TRUE)

#### plot graphs with the output data of irf()
plot.new()
plot(irf_y3_ss)

#### choose data for a graph of "U <- prod"
# choose data such that impulse = "pord"
names(irf_y3_ss)
names(irf_y3_ss$irf)

print(irf_y3_ss$irf$prod)

irf_y3_s1_mean <- irf_y3_ss$irf$prod
irf_y3_s1_lo <- irf_y3_ss$Lower$prod
irf_y3_s1_up <- irf_y3_ss$Upper$prod

#### preparing for plotting
y_data <- cbind(irf_y3_s1_mean, irf_y3_s1_lo, irf_y3_s1_up)
colnames(y_data) <- c("mean", "lower", "upper")

# Note that the initial values are not zero. 
print(y_data)
y_data <- rbind(c(0, 0, 0), y_data)
# Make sure that the initial values are zero, now. 
print(y_data)

# x_data
num_row <- nrow(y_data)
x_data <- matrix(-1:(num_row - 2), nrow = num_row, ncol = 1)
print(x_data)

# min, max information
x_min <- min(x_data)
x_max <- max(x_data)
print(c(x_min, x_max))

y_min <- min(y_data[, 2])
y_max <- max(y_data[, 3])
print(c(y_min, y_max))

#### plot, using matplot().
# response = U = y3, shock = prod = y1,
plot.new()

matplot(x_data, y_data, 
type = "l", lwd = 2, col = 1, 
lty = c("solid", "dotted", "dotted"), 
xlim = c(-1, (num_row + 15)), 
ylim = c(-0.80, 0.40), 
xlab = "time Horizon (quarter)", 
ylab = "impulse response (persent)", 
main = "impulse response: response = U = y3, shock = prod = y1, Use of vec2var()")

# additional information to the graph
abline(h = 0, col = "gray")
text(x_max, y_data[(x_data == x_max), 1], labels = "irf_y3_s1", pos = 4)
text(x_max, y_data[(x_data == x_max), 2], labels = "2.5%", pos = 4)
text(x_max, y_data[(x_data == x_max), 3], labels = "97.5%", pos = 4)
# pos = 1: below,  pos = 2: left,  pos = 3: up,  pos = 4: right.

#### save the graph as a file
# dev.copy(jpg, file = "./outputs/irf_vec2var_vars.jpg")
# dev.off()

#### end #############################################
