#### R script ########################################
# Last modfied: 2019-09-09
# File name: fevd_vec2var.R
# Keywords for namimg: 
#   fevd: forecast error variance decompotition, 
#   vec2var: a VAR model transformed from a VEC model, using vec2var()
# 
# Written by: Hiroshi Murao
#
# Purpose: perfome the forecast error variance decompotition
#
# Data source: data set called "Canada".  
#    This data set is used for package 'vars' of software R.
#   	
# Data:	
#   Sample periods: 1980:1 2000:4;
#   Variable names:		
#     prod = log of per capita output 
#     e = log of employment 		
#     U = unemployment rate, without log 		
#     rw = manufacturing real wage
#
##########################################################
#### first things to do 
# setwd("C:/book_VAR/data_works/Canada/R_prg")
setwd("J:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration
search()

#### get data
data(Canada)
print("Check the data@set of Canada")
print(Canada)

#### Johansen procedure for VAR, using ca.jo()
out_cajo <- ca.jo(Canada[, c("prod", "e", "U", "rw")], type = "trace", ecdet = "trend", K = 3, spec = "transitory")

#### Transform a VECM to VAR in levels, using vec2var()
out_vec2var <- vec2var(out_cajo, r = 1)
print(out_vec2var)

#### forecast error variance decomposition, using fevd() 
fevd_vec2var <- fevd(out_vec2var, n.ahead = 48)

#### check the data structure of the output from fevd()
print(fevd_vec2var)
summary(fevd_vec2var)
names(fevd_vec2var)
str(fevd_vec2var)
print(fevd_vec2var$U)

#### choose some data for a graph.
# choose data such that response = "U"
fevd_U_all <- fevd_vec2var$U
print(fevd_U_all)
# colnames in matrix: "prod", "e", "U", "rw"

#### preparing for plotting
# get y_data
y_data <-fevd_U_all
colnames(y_data) <- c("fevd_U_prod", "fevd_U_e", "fevd_U_U", "fevd_U_rw")
# note that the values at the first row are not zero.
print(y_data)

# get x_data
num_H <- nrow(y_data)
x_data <- matrix(1:num_H, nrow = num_H, ncol = 1)
print(x_data)

# min, max information
x_max <- max(x_data)
x_min <- min(x_data)
print(c(x_min, x_max))

y_min <- min(y_data)
y_max <- max(y_data)
print(c(y_min, y_max))

#### plot x-y curves, using matplot().
plot.new()

matplot(x_data, y_data, type = "l", lwd = 2, col = 1, 
lty = c("solid", "dotted", "dashed", "longdash"), 
xlim = c(-1, (num_H + 15)), 
ylim = c(-0.2, 1.0), 
xlab = "time horizon (quarter)", 
ylab = "relative variance contribution (RVC)", 
main = "Forecast error variance decomposition: U <- all. Based on vec2var()")

# add curve labels
abline(h = 0, col = "gray")
text(x_max, y_data[(x_data == x_max), 1], labels = "fevd_U_prod", pos = 4)
text(x_max, y_data[(x_data == x_max), 2], labels = "fevd_U_e", pos = 4)
text(x_max, y_data[(x_data == x_max), 3], labels = "fevd_U_U", pos = 4)
text(x_max, y_data[(x_data == x_max), 4], labels = "fevd_U_rw", pos = 4)
# pos = 1: below,  pos = 2: left,  pos = 3: up,  pos = 4: right.

# save the graph as a file
# dev.copy(pdf, file = "outputs/fevd_VAR.pdf")
# dev.off()

#### end #############################################
