#### R script ########################################
# Last modfied: 2019-08-23
# File name: test_cousality_vars.R
# Keywords: Granger causality test, 
#  using causality() function in Package "vars",
#  
# Written by: Hiroshi Murao
#
# Purposes: perform the Granger causality tests,
#    using causality() function in Package "vars".
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 - 2004:4
#
# List of variables:
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars)

### get data
data(Canada)
print("The data@set of Canada")
print(Canada[1:5], )
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]
print(ys_level[1:5, ])

ys_diff <- diff(Canada[, c("prod", "e", "U", "rw")], lag = 1)
print(ys_diff[1:5, ])

### estimate a VAR model, using VAR() function in "vars"
# VAR_level <- VAR(y = ys_level, p = 3, type = "both", exogen = NULL)
VAR_diff <- VAR(y = ys_diff, p = 2, type = "const", exogen = NULL)

print(VAR_diff)

### Granger causality tests, using causality() function in "vars"
# cause = "e"
causalTest_e <- causality(x = VAR_diff, cause = "e", 
   vcov = NULL, boot = TRUE, boot.runs = 100) 

print(causalTest_e)

# cause = "e" and "prod"
cuasalTest_prod_e <- causality(x = VAR_diff, cause = c("prod", "e"), 
   vcov = NULL, boot = TRUE, boot.runs = 100) 

print(cuasalTest_prod_e)

#### end #############################################
