#### R script ########################################
# Last modfied: 2019-09-09
# File name: predic_vec2var_vars.R
# Keywords: prediction based on VAR(p),
#   using predict() function in Package "vars",
#   using vec2var() function in Package "vars",
#   A VEC model is stranfomed to a VAR model, 
#  
# Written by: Hiroshi Murao
#
# Purpose: perform the prediction based on a VAR model.
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root and cointegration tests

#### data preparations
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

ys_level <- Canada[, c("prod", "e", "U", "rw")]
print(ys_level[1:5, ])

Canada_diff <- diff(Canada[, c("prod", "e", "U", "rw")], lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- na.omit(Canada_diff)
print(ys_diff[1:5, ])

#### Johansen procedure for VAR, using ca.jo()
out_cajo <- ca.jo(x = ys_level, type = "trace", 
   ecdet = "trend", K = 3, spec = "transitory")

#### transform VEC to VAR in level, using vec2var()
out_vec2var <- vec2var(out_cajo, r = 1)
print(out_vec2var)
summary(out_vec2var)

#### predict, usig predict() in "vars"
predict_vec2var <- predict(out_vec2var, n.ahead = 12, 
   ci = 0.95, dumvar = NULL)

#### plot using the output from predict() 
plot.new()
plot(predict_vec2var)

#### prepare for better plotting
# check names in the output
names(predict_vec2var)
print(predict_vec2var$fcst)

# get y_data
y_data <- predict_vec2var$fcst$prod

# y_data has 4 columns: "fcst", "lower", "upper", "CI"
print(y_data[1:5, ])

# min, max information
y_min <- min(y_data[, 2])
y_max <- max(y_data[, 3])
print(c(y_min, y_max))

# get x_data
num_H <- nrow(y_data)
x_data <- matrix(1:num_H, nrow = num_H, ncol = 1)
print(x_data)

# min, max information
x_min <- min(x_data)
x_max <- max(x_data)
print(c(x_min, x_max))

#### plot, using matplot().
plot.new()

matplot(x_data, y_data[, 1:3], 
type = "l", lwd = 2, col = 1, 
lty = c("solid", "dotted", "dotted"), 
xlim = c(1, (num_H + 6)), 
ylim = c(410, 430), 
xlab = "time horizon (quarter)", 
ylab = "forecast value of y1", 
main = "forecast, y1 = prod, Use of vec2var()")

# additional information to the graph
abline(h = 0, col = "gray")
text(x_max, y_data[(x_data == x_max), 1], labels = "predicted y1", pos = 4)
text(x_max, y_data[(x_data == x_max), 2], labels = "2.5%", pos = 4)
text(x_max, y_data[(x_data == x_max), 3], labels = "97.5%", pos = 4)
# pos = 1: below,  pos = 2: left,  pos = 3: up,  pos = 4: right.

#### save the graph as a file
# dev.copy(jpg, file="outputs/predic_vec2var.jpg")
# dev.off()

###### end #############################################
