#### R script ########################################
# Last modfied: 2019-09-09
# File name: test_pgff.R
# Keywords: unit root test,
#   using pgff.test() function in Package "egcm",  
#   Pantula, Gonzales-Farias, and Fuller test, 
#
# Written by: Hiroshi Murao
#
# Purpose: perform the test of unit root, 
#    using pgff() in "egcm". 
#
# Related journal paper: Breitung J, Bruggemann R, Lutkepohl H (2004) 
# "Structural Vector Autoregressive Modeling and Impulse Responses". 
# In Lutkepohl H, Kratzig M (eds), "Applied Time Series Econometrics", 
# chapter 4, pp.159-196, Cambridge University Press, 
# ISBN 0-521-83919-X (hardback). - ISBN 0-521-54787-3 (paperback)  
#
# Data set name: "Canada" in Package "vars"
# Data type: Canada quarterly data
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index  
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration
library(egcm) # Engle-Granger Cointegration Method

#### get data
# R package "vars" contains the data set "Canada" 
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

#### Pantula, Gonzales-Farias, and Fuller test, 
# using pgff.test() in "egcm"
# variable "prod"
pgff_prod <- pgff.test(Y = Canada[, "prod"], detrend = TRUE) 
print(pgff_prod)

names(pgff_prod)
print(pgff_prod$statistic)
print(pgff_prod$alternative)
print(pgff_prod$p.value)
print(pgff_prod$method)
print(pgff_prod$data.name)

pgff_prod_diff <- pgff.test(Y = diff(Canada[, "prod"], lag = 1), detrend = TRUE) 
print(pgff_prod_diff)

#### experiments 
prod <- Canada[, "prod"]
prod_diff <- diff(prod)
print(cbind(prod, prod_diff))

#### end #############################################
