#### R script ########################################
# Last modfied: 2019-09-09
# File name: test_ur_df.R
# Keywords: unit root test, Augmented Dickey-Fuller test, 
#    using ur.df() function in Package "urca",   
#
# Written by: Hiroshi Murao
#
# Purpose: perform the test of unit root, 
#    using ur.df() function in "urca". 
#
# Related journal paper: 
# Breitung J, Bruggemann R, Lutkepohl H (2004) 
# "Structural Vector Autoregressive Modeling and Impulse Responses". 
# In Lutkepohl H, Kratzig M (eds), "Applied Time Series Econometrics", 
# chapter 4, pp.159-196, Cambridge University Press, 
# ISBN 0-521-83919-X (hardback). - ISBN 0-521-54787-3 (paperback)  
#
# Data set: "Canada" in Package "vars"
# Data type: Canadian quarterly data
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index  
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfass_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration

#### get data
# R package "vars" contains the data set "Canada" 
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

#### Augmented Dickey-Fuller test, using ur.df() in "urca"
# variable: "prod"
prod <- Canada[, "prod"]
urdf_prod_trend <- ur.df(y = prod, type = "trend", selectlags = "AIC") 
summary(urdf_prod_trend)

urdf_prod_drift <- ur.df(y = prod, type = "drift", selectlags = "AIC")
summary(urdf_prod_drift)

urdf_prod_none <- ur.df(y = prod, type = "none", selectlags = "AIC")
summary(urdf_prod_none)

# test with "prod_diff"
prod_diff <- diff(Canada[, "prod"], lag = 1)
print(prod_diff[1:5])

urdf_prod_diff_drift <- ur.df(y = prod_diff, type = "drift", selectlags = "AIC")
summary(urdf_prod_diff_drift)

#### end #############################################
