#### R script ########################################
# Last modfied: 2019-11-04
# File name: test_ur_ers.R
# Keywords: unit root test, Elliott-Rothemberg-Stock test, 
#   using ur.ers() function in Package "urca", 
#   Elliott-Rothemberg-Stock (ERS) test = ADF-GLS test,
#
# Written by: Hiroshi Murao
#
# Purpose: perform the test of unit root, 
#   using ur.ers() in "urca".   
#
# Data set: "Canada" in Package "vars"
# Data type: Canadian quarterly data
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index  
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration

#### get data
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

#### ERS test = ADF-GLS test, using ur.ers() in "urca"
# variable: "prod"
prod <- Canada[, "prod"]
DF_GLS_prod_trend <- ur.ers(prod, type = "DF-GLS", 
  model = "trend", lag.max = 6) 
summary(DF_GLS_prod_trend)

DF_GLS_prod_const <- ur.ers(y = prod, type = "DF-GLS", 
  model = "constant", lag.max = 6) 
summary(DF_GLS_prod_const)

# test with "prod_diff"
prod_diff <- diff(Canada[, "prod"], lag = 1)
print(prod_diff)

DF_GLS_prod_diff_const <- ur.ers(y = prod_diff, type = "DF-GLS", 
  model = "constant", lag.max = 6) 
summary(DF_GLS_prod_diff_const)

# test with "prod_diff2"
prod_diff2 <- diff(prod_diff, lag = 1)
print(prod_diff2[1:5])

DF_GLS_prod_diff2_const <- ur.ers(y = prod_diff2, type = "DF-GLS", 
  model = "constant", lag.max = 6) 
summary(DF_GLS_prod_diff2_const)

#### end #############################################
