#### R script ########################################
# Last modfied: 2021-03-07
# File name: test_urkpss_urca.R
# Keywords: unit root test, 
#   using ur.kpss() function in Package "urca",
#   Kwiathowaski-Phillips-Schmidt-Shin (KPSS) test,
# 
# Written by: Hiroshi Murao
#
# Purpose: perform the tests of unit root, 
#   using ur.kpss() in "urca".  
#
# Data set: "Canada" in Package "vars"
# Data type: Canadian quarterly data
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index  
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfass_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration

#### get data
# R package "vars" contains the data set "Canada" 
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

#### unit root tests, using ur.kpss() in "urca"
# test with "prod"
prod <- Canada[, "prod"]

kpss_prod  <- ur.kpss(y = prod, type = "tau", lags = "long")
summary(kpss_prod)

# test with "prod_diff"
# make differenced data
prod_diff <- diff(Canada[, "prod"], lag = 1)
print(prod_diff[1:5])

kpss_prod_diff <- ur.kpss(y = prod_diff, type = "tau", lags = "long") 
summary(kpss_prod_diff)

#### end #############################################
