#### R script ########################################
# Last modfied: 2019-11-04
# File name: test_ur_pp.R
# Keywords: unit root test,
#  using ur.pp() function in Package "urca",
#  Phillips-Perron test, 
#
# Written by: Hiroshi Murao
#
# Purpose: perform the test of unit root, 
#    using ur.pp() in "urca".   
# 
# Data set: "Canada" in Package "vars"
# Data type: Canadian quarterly data
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index  
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration

#### get data
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

#### Phillips-Perron test, using ur.pp()
# variable: "prod"
# type = "Z-tau"
prod <- Canada[, "prod"]
Z_tau_prod_trend <- ur.pp(x = prod, type = "Z-tau", 
  model = "trend", lags = "short", use.lag = NULL) 
summary(Z_tau_prod_trend)

Z_tau_prod_const <- ur.pp(x = prod, type = "Z-tau", 
model = "const", lags = "short", use.lag = NULL) 
summary(Z_tau_prod_const)

# test with "prod_diff"
prod_diff <- diff(Canada[, "prod"], lag = 1)
print(prod_diff[1:5])

Z_tau_prod_diff_const <- ur.pp(x = prod_diff, type = "Z-tau", 
  model = "const", lags = "short", use.lag = NULL) 
summary(Z_tau_prod_diff_const)

#### type = "Z-alpha"
Z_alpha_prod_trend <- ur.pp(x = prod, type = "Z-alpha", 
  model = "trend", lags = "short", use.lag = NULL) 
summary(Z_alpha_prod_trend)

Z_alpha_prod_const <- ur.pp(x = prod, type = "Z-alpha", 
  model = "const", lags = "short", use.lag = NULL) 
summary(Z_alpha_prod_const)

# test with "prod_diff"
Z_alpha_prod_diff_const <- ur.pp(x = prod_diff, type = "Z-alpha", 
  model = "const", lags = "short", use.lag = NULL) 
summary(Z_alpha_prod_diff_const)

#### end #############################################
