#### R script ########################################
# Last modfied: 2021-06-25
# File name: test_ur_za.R
# Keywords: unit root test,  
#   using of ur.za() function in Package "urca",
#   Zivot and Andrews test,
#  
# Written by: Hiroshi Murao
#
# Purpose: perform unit root tests, 
#    using ur.za() function in Package "urca".  
#
# Data source: R package "vars"
# Data set name: Canada
# Data type: Canada quarterly data
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index  
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfass_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration

#### get data
# R package "vars" contains the data set "Canada" 
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

#### unit root tests, using ur.za() in "urca"
# (1) test with y1 = "prod"
y1 <- Canada[, "prod"]

urza_y1_both <- ur.za(y = y1, model = "both", lag = 3)
summary(urza_y1_both)

# (2) test with y2 = "e"
y2 <- Canada[, "e"]

urza_y2_both <- ur.za(y = y2, model = "both", lag = 3)
summary(urza_y2_both)

# (3) test with y3 = "U"
y3 <- Canada[, "U"]

urza_y3_both <- ur.za(y = y3, model = "both", lag = 3)
summary(urza_y3_both)

# (4) test with y4 = "rw"
y4 <- Canada[, "rw"]

urza_y4_both <- ur.za(y = y4, model = "both", lag = 3)
summary(urza_y4_both)

#### end #############################################
