#### R script ########################################
# Last modfied: 2019-09-09
# File name: test_ca_jo.R
# Keywords: cointegration test, 
#   using ca.jo() function in Package "urca",
#   Johansen test,  
#
# Written by: Hiroshi Murao
#
# Data set: "Canada" in Package "vars"
# Data type: Canadian quarterly data
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars) # VAR
library(urca) # unit root, cointegration
search()

#### get data
# R package "vars" contains the data set "Canada" 
data(Canada)
print("The data@set of Canada")
print(Canada[1:5, ])

ys_level <- Canada[, c("prod", "e", "U", "rw")]

#### get information for lag selection
out_VARselect <- VARselect(ys_level, type = "both", lag.max = 8)
print(out_VARselect)

#### Johansen cointegration test, using ca.jo()
# K = 3, trend

cajo_trace_trend_K3 <- ca.jo(ys_level, type="trace", 
   ecdet = "trend", K = 3, spec =" transitory")
summary(cajo_trace_trend_K3)

cajo_eigen_trend_K3 <- ca.jo(ys_level, type="eigen", 
    ecdet = "trend", K = 3, spec = "transitory")
summary(cajo_eigen_trend_K3)

# K = 2, trend

cajo_trace_trend_K2 <- ca.jo(ys_level, type = "trace", 
    ecdet = "trend", K = 2, spec = "transitory")
summary(cajo_trace_trend_K2)

cajo_eigen_trend_K2 <- ca.jo(ys_level, type = "eigen", 
   ecdet = "trend", K = 2, spec = "transitory")
summary(cajo_eigen_trend_K2)
show(cajo_eigen_trend_K2)

#### check the content of ca.jo() function
# showMethods(classes = "ca.jo")
# show(ca.jo)

#### end #############################################
