#### R script ########################################
# Last modfied: 2019-11-18
# File name: test_serial.R
# Keywords for file name
#    test: test of the no serial correlation
#    serial: using serial.test() function in "vars"
#  
# Written by: Hiroshi Murao
#
# Purpose: perform the test of no serial correlation, 
#    using serial.test()function.  
#
# Name of data set: "Canada" in package "vars"
#
# Sample periods: 1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("F:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars)
library(urca)

#### get data
data(Canada)
print(Canada[1:10, ])

#### use VARselect()
out_VARselect <- VARselect(Canada, lag.max = 8, type = "both")  
print(out_VARselect)

#### estimate a VAR(p) model, using VAR()
out_VAR <- VAR(Canada, p = 3, type = "both")
print(out_VAR)
summary(out_VAR)

#### tests of the no serial correlation of the error term, using serial.test()
# Portmanteau Test (asymptotic)
serialTest_PTasy <- serial.test(out_VAR, lags.pt = 16, type = "PT.asymptotic")
print(serialTest_PTasy)

# Portmanteau Test (adjusted)
serialTest_PTadj <- serial.test(out_VAR, lags.pt = 16, type = "PT.adjusted")
print(serialTest_PTadj)

# Breusch-Godfrey LM test
serialTest_BG <- serial.test(out_VAR, lags.pt = 16, type = "BG")
print(serialTest_BG)

# Edgerton-Shukur F test
serialTest_ES <- serial.test(out_VAR, lags.pt = 16, type = "ES")
print(serialTest_ES)

#### end #############################################
