#### R Script ########################################
# Last modfied: 2019-09-09
# File name: est_SVAR_vars.R
# Keywords: estimate a SVAR(p), 
#   using SVAR() function in Package "vars", 
#   This SVAR model is a trial model. 
#   The right model is a SVEC model. 
#
# Written by: Hiroshi Murao
#
# Purpose: perform the estimation a SVAR model,
#    using SVAR() function in Package "vars".
#
# Related journal paper: Breitung J, Bruggemann R, Lutkepohl H (2004) 
# "Structural Vector Autoregressive Modeling and Impulse Responses". 
# In Lutkepohl H, Kratzig M (eds), "Applied Time Series Econometrics", 
# chapter 4, pp.159-196, Cambridge University Press, 
# ISBN 0-521-83919-X (hardback). - ISBN 0-521-54787-3 (paperback)  
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars)

#### get data 
data(Canada)
print("Check the data@set of Canada")
print(Canada)
print(Canada[, 1])
print(Canada[, 2])
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]

Canada_diff <- diff(Canada, lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- Canada_diff[, c("prod", "e", "U", "rw")]
print(ys_diff[1:5, ])

#### preparational estimation, using VAR()
out_VAR <- VAR(y = ys_diff, p = 2, type = "const", exogen = NULL)

#### make Bmat for SVAR
Bmat <- diag(4)
Bmat[1, 1] <- NA
Bmat[2, 2] <- NA
Bmat[3, 3] <- NA
Bmat[4, 4] <- NA
print(Bmat)

#### make Amat for SVAR
Amat <- diag(4)
Amat[2:4, 1] <- NA
Amat[3, 2] <- NA
Amat[4, 3] <- NA
print(Amat)

#### estimate a SVAR model, using SVAR()
out_SVAR <- SVAR(x = out_VAR, estmethod = "scoring", 
   Amat = Amat, Bmat = Bmat,
   max.iter = 100, maxls = 1000, conv.crit = 1.0e-8)

summary(out_SVAR)
print(out_SVAR)

#### end #############################################
