#### R script ########################################
# Last modfied: 2019-05-26
# File name: est_SVEC_vars.R
# Keywords: estimate a SVEC(p),
#   using SVEC() function in Package "vars", 
#  
# Written by: Hiroshi Murao
#
# Purpose: perform the estimation of a SVEC model,
#   using SVEC() function in Package "vars".
#
# Related journal paper: Breitung J, Bruggemann R, Lutkepohl H (2004) 
# "Structural Vector Autoregressive Modeling and Impulse Responses". 
# In Lutkepohl H, Kratzig M (eds), "Applied Time Series Econometrics", 
# chapter 4, pp.159-196, Cambridge University Press, 
# ISBN 0-521-83919-X (hardback). - ISBN 0-521-54787-3 (paperback)  
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
# setwd("C:/school/stat_homework/time_VAR/Breitung/R_prg")
setwd("F:/book_VAR/stat_works/Pfaff_Canada/R_prg")
library(vars)

#### get data 
data(Canada)
print("Check the data@set of Canada")
print(Canada)
# summary(Canada)
ys_level <- Canada[, c("prod", "e", "U", "rw")]

Canada_diff <- diff(Canada, lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- Canada_diff[, c("prod", "e", "U", "rw")]
print(ys_diff[1:5, ])

#### Johansen procedure for VAR, using ca.jo()
out_cajo <- ca.jo(ys_level, type = "trace", 
   ecdet = "trend", K = 3, spec = "transitory")

### make the long run impact matrix
LR <- matrix(NA, nrow = 4, ncol = 4)
# a cointegration relation is interpreted as a stationary wage-setting relation.
# the column corresponding to "rw" has zero entries.
LR[1:4, 4] <- 0
# no long-run impact from ("e", "U", "rw") to "prod".
LR[1, 2:4] <- 0

#### make the contemporaneous (short run) impact matrix
SR <- matrix(NA, nrow = 4, ncol = 4)
# no contemporaneous impact from "e" to "rw".
SR[4, 2] <- 0

#### estimate a SVEC model, using SVEC() in "vars"
out_SVEC <- SVEC(out_cajo, r = 1, LR = LR, SR = SR, 
  lrtest = FALSE, boot = TRUE, runs = 100)
summary(out_SVEC)

#### end #############################################
