###### R Script ########################################
# Last modfied: 2019-09-09
# File name: est_VAR_vars.R
# Keywords: estimate a VAR(p),
#    using VAR() function in Package "vars",
#   
# Written by: Hiroshi Murao
#
# Purpose: peroform the estimation of a VAR model,
#   using VAR() function in "vars.
#
# Related journal paper: Breitung J, Bruggemann R, Lutkepohl H (2004) 
# "Structural Vector Autoregressive Modeling and Impulse Responses". 
# In Lutkepohl H, Kratzig M (eds), "Applied Time Series Econometrics", 
# chapter 4, pp.159-196, Cambridge University Press, 
# ISBN 0-521-83919-X (hardback). - ISBN 0-521-54787-3 (paperback)  
#
# Name of data set: Canada
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars)
library(urca)

#### data preparations
data(Canada)
print("The data set of Canada")
print(Canada[1:5, ])
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]

Canada_diff <- diff(Canada, lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- Canada_diff[, c("prod", "e", "U", "rw")]
print(ys_diff[1:5, ])

#### estimate a VAR(p), using VAR() in "vars"
# out_VAR <- VAR(y = ys_level, type = "both", p = 3, ic = "AIC")
out_VAR <- VAR(y = ys_diff, type = "const", p = 2, ic = "AIC")

summary(out_VAR)

#### end #############################################
