### R Script ########################################
# Last modfied: 2019-09-09
# File name: est_VEC_urca.R
# Keywords: estimate a VEC(p),  
#    using ca.jo() function in Package "urca", 
# 
# Written by: Hiroshi Murao
#
# Purpose: Perform the estimation of a VEC model,
#   using ca.jo() function in "urca".
#
# Related journal paper: Breitung J, Bruggemann R, Lutkepohl H (2004) 
# "Structural Vector Autoregressive Modeling and Impulse Responses". 
# In Lutkepohl H, Kratzig M (eds), "Applied Time Series Econometrics", 
# chapter 4, pp.159-196, Cambridge University Press, 
# ISBN 0-521-83919-X (hardback). - ISBN 0-521-54787-3 (paperback)  
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
# setwd("C:/school/stat_homework/time_VAR/Breitung/R_prg")
setwd("C:/book_VAR/data_works/Pfaff_Canada/R_prg")
library(vars)
library(urca)

#### get data 
data(Canada)
print("Check the data@set of Canada")
print(Canada)
print(Canada[, 1])
print(Canada[, 2])
# summary(Canada)

data_use <- Canada[, c("prod", "e", "U", "rw")]
print(data_use)

#### set important numbers
num_y <- 4
num_z <- 2
num_lag <- 4
num_x <- num_lag*num_y + num_z

#### prepare for the estimation of a VEC model, using ca.jo()
out_cajo <- ca.jo(Canada[, c("prod", "e", "U", "rw")], 
  type = "trace", ecdet = "trend", K = 3, 
  spec = "transitory", season = NULL, dumvar = NULL)

# check the output of ca.jo()
summary(out_cajo)

#### estimate the VEC model, using cajorls()
out_cajorls <- cajorls(z = out_cajo, r = 1, reg.number = NULL)

# check the output of cajorls()
names(out_cajorls)
summary(out_cajorls)
print(out_cajorls)

#### end #############################################
