#### R script ########################################
# Last modfied: 2019-09-09
# File name: est_restrict_vars.R
# Keywords: estimate a restricted VAR(p),
#   using restrict() function in "vars",    
#
# Written by: Hiroshi Murao
#
# Purpose: perform the estimation of a restricted VAR(p),
#   using restrict() function in "vars".
#
# Name of data set: "Canada" in Package "vars".
#
# Sample periods:  1980:1 2004:4
#
# List of variables
#
# prod : labor productivity = log of GDP - log of employment
# e : log of employment
# U : unemplyment rate
# rw : real wage = log of real wage index 
#
#### first things to do 
setwd("C:/book_VAR/stat_works/Pfaff_Canada/R_prg")
library(vars)
library(svars)

#### data preparations
data(Canada)
dim(Canada)
print("The data set of Canada")
print(Canada[1:5, ])
# summary(Canada)

ys_level <- Canada[, c("prod", "e", "U", "rw")]

Canada_diff <- diff(Canada, lag = 1)
print(Canada_diff[1:5, ])

ys_diff <- Canada_diff[, c("prod", "e", "U", "rw")]
print(ys_diff[1:5, ])

#### estimate a VAR model, using VAR() in "vars"
# importan numbers for diff-VAR
# num_y <- 4
# num_lag <- 2
# num_z <- 1
# num_para <- num_y*num_lag + num_z 

# out_VAR <- VAR(y = ys_level, type = "both", p = 3, ic = "AIC")
out_VAR <- VAR(y = ys_diff, type = "const", p = 2, ic = "AIC")

summary(out_VAR)

#### make a matrix of restrctions
# restrict: K x num_para, 4 x 9
restrict <- rbind(c(1, 1, 1, 1, 1, 1, 0, 0, 0),
                  c(1, 0, 1, 0, 0, 1, 0, 1, 1), 
                  c(0, 0, 1, 1, 0, 1, 0, 0, 1),
                  c(1, 1, 1, 0, 1, 1, 0, 1, 0))
# nrow = 4, ncol = 9, byrow = TRUE)
print(restrict)

#### estimate the restricted VAR model, using restrict() in "vars"
out_VAR_rst <- restrict(out_VAR, method = "man", resmat = restrict)
summary(out_VAR_rst)

#### end #############################################
