#### R script ########################################
# Last modfied: 2019-09-29
# File name: resid_reg_OK.R
# Keywords: residual regression OK,
#   residual regression works well, 
#
# Written by: Hiroshi Murao
#
# Purpose: Perform the residual regression 
#     with a model of the apple demand curve. 
#
# Original data source: ƌvN published by v
# The data can be obtained by visiting the following Web sites.
# vǁƌvN񁁁ʁlȏ̐сPONxN񁁁v\PV\@
# Hu؁ECiN؁jv`uʕv
#
# The following is a list of variable names in the data set. 
#
# year
# EXP_fresh_fruit	Q_fresh_fruit	PN_fresh_fruit	P_fresh_fruit	
# EXP_apple	Q_apple	PN_apple	P_apple	
# EXP_mandarin	Q_mandarin	PN_mandarin	P_mandarin	
# EXP_pear	Q_pear	PN_pear	P_pear	
# EXP_grape	Q_grape	PN_grape	P_grape	
# EXP_persimmon	Q_pwersimmon	PN_persimmon	P_persimmon	
# EXP_peach	Q_peach	PN_peach	P_peach	
# EXP_watermelon	Q_watermelon	PN_watermelon	P_watermelon	
# EXP_melon	Q_melon	PN_melon	P_melon	
# EXP_strawberry	Q_strawberry	PN_strawberry	P_strawberry	
# EXP_banana	Q_banana	PN_banana	P_banana	
# EXP_other_fruit	Q_other_fruit	PN_other_fruit	P_other_fruit	
# CPI
# income
# time
#
#### first things to do 
setwd("C:/book_VAR/data_works/data_apple_JP/R_prg")

#### data preparations
in_data <- read.csv("./data/apple_JP.csv")
#print(cbind(in_data$year, in_data$Q_apple))
names(in_data)
print(in_data$Q_apple)

logQ_apple <- log(in_data$Q_apple)
logP_apple <- log(in_data$P_apple)
logIncome <- log(in_data$income)
logP_persimmon <- log(in_data$P_persimmon)
time <- in_data$time

#### regression with the whole model, using lm()
out_whole <- lm(logQ_apple ~ logP_apple + logIncome + logP_persimmon + time)
# out_whole <- lm(log(Q_apple) ~ log(P_apple) + log(income) + log(P_persimmon) + time, data = in_data)
  
summary(out_whole)
names(out_whole)

#### residual regression, using lm()
## first regression without logP_apple
out_Q <- lm(logQ_apple ~ logIncome + logP_persimmon + time)
names(out_Q)
logQ_apple_dev <- out_Q$residuals 

out_P <- lm(logP_apple ~ logIncome + logP_persimmon + time)
names(out_P)
logP_apple_dev <- out_P$residuals 

## second regression
out_resid_reg <- lm(logQ_apple_dev ~ 0 + logP_apple_dev)
summary(out_resid_reg)

#### show results 
# logP_apple     -0.596195 
# logP_apple_dev  -0.5962

print(out_whole$coefficients)
names(out_whole$coefficients)
print(out_whole$coefficients[2])

print(out_resid_reg$coefficients)

compare_coeffs <- c(out_whole$coefficients[2],out_resid_reg$coefficients)

# print the results
print("The results of our interest") 
print(compare_coeffs)

#### end #############################################
