#### R script ########################################
# Last modfied: 2019-12-06
# File name: read_macro_JP.R
# Keywords: read the data of "macro_JP.csv",  
#       about Japanese Macro Economics.
#
# Written by: Hiroshi Murao 
#
# Purpose: Read the data "macro_JP.csv" and plot some graphs.
#
# Data source: Statistical Bureau of Japan vǁEvZ^[
#    Japan's Long-term Histrical Time Series n
#
# Original data sets: 3́@oόvZ, 4 ʉ݁Ez, 14́@ZEی, 19́@JE
#
# The following variables are made for an IS-LM model.
#
# YEAR: 1969 ~ 1998
# CP: private consumption 
# IP: private investment 	
# R: interest rate (%)	
# Y: income = GDP	
# YD: disposable income
# TAX: tax = Y - YD 
# GOV: govenment spending = Y - CP - IP 
# P: price level = GDP deflator (100 at 1990)
# MS: nominal money supply = M2CD 		
# MP: real money supply = MS/P 	
#
##########################################################
#### first things to do 
setwd("C:/book_VAR/data_works/data_macro_JP/R_prg")

#### read data 
# It is important to use "stringsAsFactors = FALSE" 
# since the data set contains "NA".
in_data <- read.csv("./data/macro_JP.csv", 
   na.strings = c("", ".", "NA", "#N/A"), stringsAsFactors = FALSE)
#
# in_data <- read.xlsx("./data/macro_JP.xlsx", 
# sheet = 1, startRows = 1, colName = T, rowName = F, stringsAsFactors = FALSE)
#
# in_data <- read_excel("./data/macro_JP.xlsx", 
# sheet = 1, startRows = 1, colName = T, rowName = F, stringsAsFactors = FALSE)

print(in_data[1:10, ])

# Check a variable with "NA".
R_test <- in_data$R_LENDING_BANK
print(R_test)
# Notice that the values in R_test are letter-type.

# Another check a variable with "NA".
R_test_2 <- as.numeric(in_data$R_LENDING_BANK)
print(R_test_2)
# Notice that the values in R_test_2 are numeric.

#### make variables for an IS-LM model
# R_LENDING_BANK has "NA" for YEAR =< 1968.
noNA <- subset(in_data, YEAR >= 1969)
print(noNA[1:10, ])

year <- noNA$YEAR
# monetary unit: trillion yen
CP <- noNA$CP/1000
IP <- noNA$IP/1000
Y <- noNA$GDP/1000

YD <- ((noNA$NDI_nominal/noNA$PGDP)*100)/1000
TAX <- Y - YD
print(cbind(Y, YD, TAX))

GOV <- Y - CP - IP
# GOV <- noNA$CG + noNA$IG + noNA$INVENTO + noNA$NX

# Use as.numeric() for a variable containing "NA".
R <- as.numeric(noNA$R_LENDING_BANK)
# R <- noNA$R_LENDING_BANK
print(R)

# P = 1 at year of 1990.
P <- noNA$PGDP/100
print(P)

# Use as.numeric() for a variable containing "NA".
MS <- as.numeric(noNA$M2CD)/10000
# The following line does not work.
# MS <- noNA$M2CD/10000
print(MS)

MP <- MS/P
print(MP)

#### preparations for graphs
x_data <- year
max_x <- max(x_data)
min_x <- min(x_data)

# y_data = (Y, CP, IP) = (GDP, Consumption, Investment)
y_data <- cbind(Y, CP, IP)
print(y_data[1:10, ])

#### graph for (Y, CP, IP) = (GDP, Consumption, Investment)
max_y <- max(y_data)
min_y <- min(y_data)
print(c(min_y, max_y))

plot.new()

matplot(x_data, y_data, 
type = "l", lwd = 2, col = 1, 
lty = c("solid", "dashed", "dotted", "dotdash", "longdash"), 
xlim = c(1969, 2005), 
ylim = c(0, 500), 
xlab = "Year", 
ylab = "Monetary value (trillion yen)") 

# add curve labels and the like
# abline(h = 0, col = "gray")
text(max_x, y_data[(x_data == max_x), 1], labels = "Y", pos = 4)
text(max_x, y_data[(x_data == max_x), 2], labels = "C", pos = 4)
text(max_x, y_data[(x_data == max_x), 3], labels = "I", pos = 4)

#### graph for R (Interest rate)
max_R <- max(R)
min_R <- min(R)
print(c(min_R, max_R))

plot.new()

matplot(x_data, R, 
type = "l", lwd = 2, col = 1, 
lty = c("solid", "dashed", "dotted", "dotdash", "longdash"), 
xlim = c(1969, 2005), 
ylim = c(0, 10), 
xlab = "Year", 
ylab = "Interest rate (%)") 

# abline(h = 0, col = "gray")
text(max_x, R[x_data == max_x], labels = "R", pos = 4)

#### graph for P (Price level)
max_P <- max(P)
min_P <- min(P)
print(c(min_P, max_P))

plot.new()

matplot(x_data, P, 
type = "l", lwd = 2, col = 1, 
lty = c("solid", "dashed", "dotted", "dotdash", "longdash"), 
xlim = c(1969, 2005), 
ylim = c(0.000, 1.2), 
xlab = "Year", 
ylab = "Price level P (P = 1 at year of 1990)") 

# abline(h = 1, col = "gray")
text(max_x, P[x_data == max_x], labels = "P", pos = 4)

#### graph for MP (real money supply)
max_MP <- max(MP)
min_MP <- min(MP)
print(c(min_MP, max_MP))

plot.new()

matplot(x_data, MP, 
type = "l", lwd = 2, col = 1, 
lty = c("solid", "dashed", "dotted", "dotdash", "longdash"), 
xlim = c(1969, 2005), 
ylim = c(100, 600), 
xlab = "Year", 
ylab = "Real money supply M/P (trillion yen)") 

#### additional information to the graph
# abline(h = 0, col = "gray")
text(max_x, MP[x_data == max_x], labels = "M/P", pos = 4)

### compute: Japanese Marginal Propensity to Consume (MPC)
C_eq <- lm(CP ~ 1 + YD)
summary(C_eq)

#### end #############################################
